#!/usr/bin/sh

# rozb3-dnf
# Copyright (c) 2021 Maurice Zhou
#
# based on https://github.com/wesbarnett/snap-pac
# Copyright (C) 2016, 2017, 2018 James W. Barnett
#
# SPDX-License-Identifier: GPL-3.0-or-later

set -eu;

# error message
out () { echo "dnf boot environment ->" "$@" ; } 1>&2
err () { out "error:" "$@" ; }
warn () { out "warning:" "$@" ; }
msg () { out "$@" ; }
die1 () { err "$@"; exit 1 ; }
die0 () { err "$@"; exit ; }

preOrPost="${1:-unset}"
[ -f /etc/rozb3-dnf.cfg ] && . /etc/rozb3-dnf.cfg

if [ "${ROZB3_DNF_SKIP:-false}" != "false" ]; then
        die0 "ROZB3_DNF_SKIP set, exit";
fi;

bePrefix="dnf";
beUuid=$(dd if=/dev/urandom of=/dev/stdout bs=1 count=100 2>/dev/null |tr -dc 'a-z0-9' | cut -c-6);
toBe="${bePrefix}-${beUuid}";

if [ "$PPID" = "" -o "$(ps -q $PPID -o args=)" = "" ]; then
    Cmd="empty_PPID";
else
    Cmd="$(ps -q $PPID -o args= | sed 's| |_|g' | sed 's|.*/||g')";
fi

beLabel="${preOrPost} ${Cmd}";

if bieaz create "$toBe"; then
        bieaz label "$toBe" "$beLabel"
        msg "created for ${preOrPost%_}-transaction: $toBe"
else
        msg "failed to create"
fi

if [ "${preOrPost}" = "post" ]; then
        if [ "${ROZB3_DNF_KEEP:-false}" != "false" ]; then
                msg "purging old boot environments; keep ${ROZB3_DNF_KEEP}"
                bieaz list -H \
                        |  cut -f1 \
                        |  tail -n+$(( "${ROZB3_DNF_KEEP}" + 1 )) \
                        |  while read i; do bieaz destroy $i 1> /dev/null; done \
                        || true
        fi
fi
